@@ -8,11 +8,12 @@ mode of execution and interaction.
 #Standard Library Modules
 import argparse
 import sys
-import os.path
+import os
 import shutil
 import logging
 import traceback
 import multiprocessing
+import subprocess
 
 #OpenAccess_EPUB Modules
 from ._version import __version__
@@ -70,7 +71,7 @@ def OAEParser():
                        help='''Use to specify a batch directory for parallel
                                processing.''')
     modes.add_argument('-C', '--collection', action='store', default=False,
-                       nargs='?', const='True',
+                       nargs='?', const=True,
                        help='''Use to combine all xml files in the local
                                directory into a single ePub collection.
                                Typing a string after this flag will provide a
@@ -200,8 +201,8 @@ def batch_input(args, config=None):
 
         #Running epubcheck on the output verifies the validity of the ePub,
         #requires a local installation of java and epubcheck.
-        #if args.no_epubcheck:
-            #epubcheck('{0}.epub'.format(output_name), config)
+        if args.no_epubcheck:
+            epubcheck('{0}.epub'.format(output_name), config)
     error_file.close()
 
 
@@ -250,9 +251,19 @@ def collection_input(args, config=None):
         dir_exists(output_name)
     epub_base = os.path.join(CACHE_LOCATION, 'base_epub')
     shutil.copytree(epub_base, output_name)
-    
+
     if args.collection is True:
-        title = output_name
+        try:
+            title_txt = open('title.txt', 'r')
+        except IOError:  # No title.txt
+            title = output_name
+        else:
+            title = title_txt.readline().strip()
+            title_txt.close()
+            if not title:
+                title = output_name
+                print('title.txt was empty or title was not on first line!')
+                print('Defaulting to name of parent directory. {0}'.format(title))
     else:
         title = args.collection
     
@@ -456,7 +467,7 @@ def epubcheck(epubname, config=None):
     elif not e == '.epub':
         print('Warning: Filename extension is not \'.epub\', appending it...')
         epubname += '.epub'
-    os.execlp('java', 'OpenAccess_EPUB', '-jar', config.epubcheck, epubname)
+    subprocess.call(['java', '-jar', config.epubcheck, epubname])
 
 def get_config_module():
     """
